{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_id %}create_notif_method_form{% endblock %}
{% block form_action %}{{ action_url }}{% endblock %}

{% block modal-header %}{% trans "Create Notification Method" %}{% endblock %}

{% block modal-body %}
    <div class="left">
         <fieldset>
        {% include "horizon/common/_form_fields.html" %}
        </fieldset>
    </div>
    <div class="right quota-dynamic">
    <h3>{% trans "Description" %}:</h3>
    <p>{% blocktrans %}
      The Name field is used to identify the notification method.
    {% endblocktrans %}</p>
    <p>{% blocktrans %}
      The Type field indicates how the notification is sent when an alarm is triggered.
    {% endblocktrans %}</p>
    <p>{% blocktrans %}
      The Address field indicates the email address, URL, or PagerDuty service
      key to be notified.
    {% endblocktrans %}</p>
    <p>{% blocktrans %}
      A non-zero value in the period field indicates how frequently a notification
      should be resent (only valid for webhook urls).
    {% endblocktrans %}</p>
  </div>

{% endblock %}

{% block modal-footer %}
  <a href="{{ cancel_url }}" class="btn btn-default cancel">{% trans "Cancel" %}</a>
  <input class="btn btn-primary" type="submit" value="{% trans "Create Notification Method" %}" />
{% endblock %}
